@@ -90,12 +90,13 @@ def lineplot(
 
     y_scale_kwarg = {"zero": False}
     if log_y:
+        y_scale_kwarg["type"] = "log"
         y_scale_kwarg["base"] = 10
     if limits is not None:
         y_scale_kwarg["domain"] = limits
 
     y_kwarg = {}
-    y_kwarg["scale"] = alt.Scale(**y_kwarg_scale)
+    y_kwarg["scale"] = alt.Scale(**y_scale_kwarg)
 
     if y_axis is not None:
         y_kwarg["axis"] = y_axis
